=====================
Installing Manrododex
=====================

From PyPI
=========

- First time install : ``pip install manrododex``
- Updating : ``pip install --upgrade manrododex``

From Source
===========

1. Clone the repo : ``git clone https://github.com/Sydiepus/Manrododex.git``
2. Go into the folder : ``cd Manrododex``
3. Install with : ``pip install .``